Fix powerpc uatomic 4-byte cmpxchg (cmpd -> cmpw)
[urcu.git] / urcu.h
diff --git a/urcu.h b/urcu.h
index 69c06e409ddaf2bb95d96d27ae6d9369b777d40b..92411398383a86909ae55650c18f04d5b395bb50 100644 (file)
--- a/urcu.h
+++ b/urcu.h
  */
 #include <urcu-pointer.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif 
+
 /*
  * Important !
  *
@@ -88,8 +92,12 @@ extern void rcu_register_thread(void);
 extern void rcu_unregister_thread(void);
 
 /*
* Explicit urcu initialization, for "early" use within library constructors.
  */
-extern void urcu_init(void);
+extern void rcu_init(void);
+
+#ifdef __cplusplus 
+}
+#endif
 
 #endif /* _URCU_H */
This page took 0.023147 seconds and 4 git commands to generate.
@@ -88,8 +92,12 @@ extern void rcu_register_thread(void);
 
 /*
- * Explicit urcu initialization, for "early" use within library constructors.
+ * Explicit rcu initialization, for "early" use within library constructors.
  */